@@ -1,6 +1,6 @@
 /*
  * grunt-contrib-internal
- * http://gruntjs.com/
+ * https://gruntjs.com/
  *
  * Copyright (c) 2016 Tyler Kellen, contributors
  * Licensed under the MIT license.
@@ -9,14 +9,14 @@
 'use strict';
 
 module.exports = function(grunt) {
-  grunt.registerTask('contrib-ci', 'Normalizes AppVeyor and Travis CI configs.', function(skipIfExists) {
+  grunt.registerTask('contrib-ci', 'Normalizes AppVeyor and Travis CI configs.', skipIfExists => {
     skipIfExists = skipIfExists === 'skipIfExists';
 
-    var path = require('path');
-    var travis = grunt.file.read(path.join(__dirname, '..', '.travis.yml'));
-    var appveyor = grunt.file.read(path.join(__dirname, '..', 'appveyor.yml'));
-    var taskTravis = path.join(process.cwd(), '.travis.yml');
-    var taskAppveyor = path.join(process.cwd(), 'appveyor.yml');
+    const path = require('path');
+    const travis = grunt.file.read(path.join(__dirname, '..', '.travis.yml'));
+    const appveyor = grunt.file.read(path.join(__dirname, '..', 'appveyor.yml'));
+    const taskTravis = path.join(process.cwd(), '.travis.yml');
+    const taskAppveyor = path.join(process.cwd(), 'appveyor.yml');
 
     if (!skipIfExists || !grunt.file.exists(taskTravis)) {
       grunt.file.write(taskTravis, travis);
@@ -26,6 +26,5 @@ module.exports = function(grunt) {
     }
 
     grunt.log.ok('Normalized .travis.yml and appveyor.yml for grunt-contrib.');
-
   });
 };
